![Continuous integration](https://github.com/mbraak/django-mptt-admin/workflows/Continuous%20integration/badge.svg) [![Version](https://badge.fury.io/py/django-mptt-admin.svg)](https://pypi.python.org/pypi/django-mptt-admin/)

[![codecov](https://codecov.io/gh/mbraak/django-mptt-admin/branch/master/graph/badge.svg?token=YGojePND2M)](https://codecov.io/gh/mbraak/django-mptt-admin)

[![License](https://img.shields.io/pypi/l/django-mptt-admin.svg)](https://pypi.python.org/pypi/django-mptt-admin/)

# Django Mptt Admin

_Django-mptt-admin_ provides a nice Django Admin interface for [django-mptt models](https://django-mptt.readthedocs.io/).

- The source is available on [https://github.com/mbraak/django-mptt-admin](https://github.com/mbraak/django-mptt-admin).
- Documentation is available on [https://mbraak.github.io/django-mptt-admin/](https://mbraak.github.io/django-mptt-admin/).

![Screenshot](https://raw.github.com/mbraak/django-mptt-admin/master/screenshot.png)
